# eric7.Plugins.VcsPlugins.vcsMercurial.HgAddSubrepositoryDialog

Module implementing a dialog to add a sub-repository.

### Global Attributes

None

### Classes

HgAddSubrepositoryDialog | Class implementing a dialog to add a sub-repository.

### Functions

None

## HgAddSubrepositoryDialog

Class implementing a dialog to add a sub-repository.

### Derived from

QDialog, Ui_HgAddSubrepositoryDialog

### Class Attributes

None

### Class Methods

None

### Methods

HgAddSubrepositoryDialog | Constructor
__updateOk | Private slot to update the state of the OK button.
getData | Public method to get the data.
on_pathPicker_pathSelected | Private slot handling the selection of a subrepository path.
on_pathPicker_textChanged | Private slot to handle the update of the path.
on_urlEdit_textChanged | Private slot to handle the update of the URL.

### Static Methods

None

#### HgAddSubrepositoryDialog (Constructor)

HgAddSubrepositoryDialog(projectPath, parent=None)

Constructor

projectPath
  project directory name (string)
parent
  reference to the parent widget (QWidget)

#### HgAddSubrepositoryDialog.__updateOk

__updateOk()

Private slot to update the state of the OK button.

#### HgAddSubrepositoryDialog.getData

getData()

Public method to get the data.

Return:
  tuple containing the relative path within the project, the sub-repository type and the sub-repository URL (string, string, string)

#### HgAddSubrepositoryDialog.on_pathPicker_pathSelected

on_pathPicker_pathSelected(path)

Private slot handling the selection of a subrepository path.

path (str)
  path of the subrepository

#### HgAddSubrepositoryDialog.on_pathPicker_textChanged

on_pathPicker_textChanged(p0)

Private slot to handle the update of the path.

p0
  text of the path edit (string)

#### HgAddSubrepositoryDialog.on_urlEdit_textChanged

on_urlEdit_textChanged(p0)

Private slot to handle the update of the URL.

p0
  text of the URL edit (string)

Up